import os
import interactions
import mysql.connector

from dotenv import load_dotenv
from steamid import SteamID

load_dotenv()
token = os.getenv('DISCORD_TOKEN')
host = os.getenv('MYSQL_HOST')
user = os.getenv('MYSQL_USER')
password = os.getenv('MYSQL_PASSWORD')
db = os.getenv('MYSQL_DATABASE')

bot = interactions.Client(token=token)

db = mysql.connector.connect(
        host=host,
        user="root",
        password=password,
        database=db,
        )

cursor = db.cursor()

def create_tables():
    cursor.execute("CREATE TABLE discord_link ( admin_id int(10) UNSIGNED NOT NULL, discord_id bigint(20) UNSIGNED NOT NULL, steamid varchar(65) COLLATE utf8mb4_unicode_ci NOT NULL);")
    cursor.execute("CREATE TABLE sm_admins ( id int(10) UNSIGNED NOT NULL, authtype enum('steam', 'name', 'ip') COLLATE utf8mb4_unicode_ci NOT NULL, identity varchar(65) COLLATE utf8mb4_unicode_ci NOT NULL, password varchar(65) COLLATE utf8mb4_unicode_ci DEFAULT NULL, flags varchar(30) COLLATE utf8mb4_unicode_ci NOT NULL, name varchar(65) COLLATE utf8mb4_unicode_ci NOT NULL, immunity int(10) UNSIGNED NOT NULL);")
    cursor.execute("ALTER TABLE discord_link ADD PRIMARY KEY (admin_id), ADD UNIQUE KEY admin_id (admin_id), ADD UNIQUE KEY discord_id (discord_id), ADD UNIQUE KEY steamid (steamid);")
    cursor.execute("ALTER TABLE sm_admins ADD PRIMARY KEY (id), ADD UNIQUE KEY identity (identity), ADD UNIQUE KEY id (id);")
    cursor.execute("ALTER TABLE sm_admins MODIFY id int(10) UNSIGNED NOT NULL AUTO_INCREMENT;")
    cursor.execute("ALTER TABLE discord_link ADD CONSTRAINT discord_link_ibfk_1 FOREIGN KEY (admin_id) REFERENCES sm_admins (id);")

create_tables()

@bot.command(
        name="reserve_slot",
        description="Claim your reserved slot on the DM Server",
        scope=433600034983116810,
        options= [
            interactions.Option(
                name="steamid",
                description="Please provide your SteamID, from https://steamid.xyz/",
                type=interactions.OptionType.STRING,
                required=True,
                ),
            ],
        )

async def reserve_slot(ctx: interactions.CommandContext, steamid: str):
    steam_id = SteamID(steamid)
    user = ctx.user
    if steam_id.isValid() == True:
        #try:
            sql_sm = "INSERT INTO sm_admins (authtype, identity, password, flags, name, immunity) VALUES (%s, %s, %s, %s, %s, %s)"
            val_sm = ("steam", steam_id.steam2(1), "", "a", user.username, "5")
            cursor.execute(sql_sm, val_sm)
            db.commit()

            id = cursor.lastrowid

            sql_discord = "INSERT INTO discord_link (admin_id, discord_id, steamid) VALUES (%s, %s, %s)"
            print(id, user.id, steam_id.steam2(1))
            val_discord = (id, str(user.id), steam_id.steam2(1))
            cursor.execute(sql_discord, val_discord)
            db.commit()

            await ctx.send(f"You just claimed a reserved slot for: `{steam_id.steam2(1)}`!")
        #except:
            await ctx.send(f"Something failed with the database, please try again later.")

    else:
        await ctx.send(f"You failed to give a valid SteamID as it seems, please head to <https://steamid.xyz/> and check.")

bot.start()


